@@ -21,7 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "range.h"
+#include "core/range.h"
 
 #include <QList>
 #include <QStringList>
