@@ -18,7 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "sstring.h"
+#include "core/sstring.h"
 
 #include <QList>
 #include <QStringList>
@@ -28,6 +28,10 @@
 
 #include <QColor>
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
+	#define qAsConst
+#endif
+
 using namespace SubtitleComposer;
 
 void *
