@@ -18,11 +18,12 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "subtitle.h"
+#include "core/subtitle.h"
 #include "subtitleline.h"
 #include "subtitleiterator.h"
 #include "subtitleactions.h"
 #include "compositeaction.h"
+#include "scconfig.h"
 
 #include <KLocalizedString>
 
@@ -98,8 +99,7 @@ Subtitle::setPrimaryData(const Subtitle &from, bool usePrimaryData)
 			thisLine->setFormatData(fromIt.current()->formatData());
 			lines.append(thisLine);
 		}
-		InsertLinesAction a(*this, lines);
-		processAction(&a);
+		processAction(new InsertLinesAction(*this, lines));
 	} else if(thisIt.current()) {   // '*this'  had more lines than 'from'
 		for(SubtitleLine *thisLine = thisIt.current(); thisLine; ++thisIt, thisLine = thisIt.current()) {
 			thisLine->setPrimaryText(SString());
@@ -406,7 +406,7 @@ Subtitle::insertLines(const QList<SubtitleLine *> &lines, int index)
 }
 
 SubtitleLine *
-Subtitle::insertNewLine(int index, bool timeAfter, TextTarget target)
+Subtitle::insertNewLine(int index, bool insertAfter, TextTarget target)
 {
 	Q_ASSERT(index <= m_lines.count());
 
@@ -414,26 +414,30 @@ Subtitle::insertNewLine(int index, bool timeAfter, TextTarget target)
 		index = m_lines.count();
 
 	SubtitleLine *newLine = new SubtitleLine();
-	int newLineIndex = (target == Secondary) ? m_lines.count() : index;
+	const int newLineIndex = (target == Secondary) ? m_lines.count() : index;
 
-	if(timeAfter) {
+	const double linePause = (double)SCConfig::linePause();
+	const double lineDuration = (double)SCConfig::lineDuration();
+	const double lineDurationAndPause = lineDuration + linePause;
+
+	if(insertAfter) {
 		if(newLineIndex) {              // there is a previous line
-			SubtitleLine *prevLine = m_lines.value(newLineIndex - 1);
-			newLine->setTimes(prevLine->hideTime() + 100., prevLine->hideTime() + 1000.);
+			const SubtitleLine *prevLine = m_lines.value(newLineIndex - 1);
+			newLine->setTimes(prevLine->hideTime() + linePause, prevLine->hideTime() + lineDurationAndPause);
 		} else if(newLineIndex < m_lines.count()) {     // there is a next line
-			SubtitleLine *nextLine = m_lines.value(newLineIndex);
-			newLine->setTimes(nextLine->showTime() - 1100., nextLine->showTime() - 100.);
+			const SubtitleLine *nextLine = m_lines.value(newLineIndex);
+			newLine->setTimes(nextLine->showTime() - lineDurationAndPause, nextLine->showTime() - linePause);
 		} else
-			newLine->setHideTime(1000.);
-	} else {                                        // ! timeAfter
+			newLine->setHideTime(lineDuration);
+	} else {
 		if(newLineIndex < m_lines.count()) {    // there is a next line
-			SubtitleLine *nextLine = m_lines.at(newLineIndex);
-			newLine->setTimes(nextLine->showTime() - 1100., nextLine->showTime() - 100.);
+			const SubtitleLine *nextLine = m_lines.at(newLineIndex);
+			newLine->setTimes(nextLine->showTime() - lineDurationAndPause, nextLine->showTime() - linePause);
 		} else if(newLineIndex) {       // there is a previous line
-			SubtitleLine *prevLine = m_lines.at(newLineIndex - 1);
-			newLine->setTimes(prevLine->hideTime() + 100., prevLine->hideTime() + 1000.);
+			const SubtitleLine *prevLine = m_lines.at(newLineIndex - 1);
+			newLine->setTimes(prevLine->hideTime() + linePause, prevLine->hideTime() + lineDurationAndPause);
 		} else
-			newLine->setHideTime(1000.);
+			newLine->setHideTime(lineDuration);
 	}
 
 	if(target == Both || index == m_lines.count()) {
@@ -1563,5 +1567,3 @@ SubtitleCompositeActionExecutor::~SubtitleCompositeActionExecutor()
 {
 	m_subtitle.endCompositeAction();
 }
-
-
