@@ -21,9 +21,9 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "range.h"
-#include "rangelist.h"
-#include "subtitle.h"
+#include "core/range.h"
+#include "core/rangelist.h"
+#include "core/subtitle.h"
 
 #include <QString>
 #include <QList>
