@@ -23,8 +23,8 @@
 #include "outputformat.h"
 #include "lineswidget.h"
 #include "application.h"
-#include "common/fileloadhelper.h"
-#include "common/filesavehelper.h"
+#include "helpers/fileloadhelper.h"
+#include "helpers/filesavehelper.h"
 
 #include "microdvd/microdvdinputformat.h"
 #include "microdvd/microdvdoutputformat.h"
@@ -169,7 +169,7 @@ FormatManager::readSubtitle(Subtitle &subtitle, bool primary, const QUrl &url, Q
 	FileLoadHelper fileLoadHelper(url);
 	if(!fileLoadHelper.open())
 		return false;
-	QByteArray byteData = fileLoadHelper.file()->readAll();
+	QByteArray byteData = fileLoadHelper.file()->read(1024 * 1024);
 	fileLoadHelper.close();
 
 	QString stringData;
