@@ -21,8 +21,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "../outputformat.h"
-#include "../../core/subtitleiterator.h"
+#include "formats/outputformat.h"
+#include "core/subtitleiterator.h"
 
 namespace SubtitleComposer {
 class MPlayerOutputFormat : public OutputFormat
