@@ -2,8 +2,7 @@
 #define VOBSUBINPUTINITDIALOG_H
 
 /*
- * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
- * Copyright (C) 2010-2017 Mladen Milinkovic <max@smoothware.net>
+ * Copyright (C) 2017 Mladen Milinkovic <max@smoothware.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,18 +40,16 @@ public:
 		CHARS_OCR = 16
 	};
 
-	VobSubInputInitDialog(void *vob, void *spu, QWidget *parent = 0);
+	VobSubInputInitDialog(QWidget *parent = 0);
 	~VobSubInputInitDialog();
 
+	void streamListSet(const QStringList streams);
 	int streamIndex() const;
 
 	quint32 postProcessingFlags() const;
 
 private:
 	Ui::VobSubInputInitDialog *ui;
-
-	void *m_vob;
-	void *m_spu;
 };
 }
 
