@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
- * Copyright (C) 2010-2017 Mladen Milinkovic <max@smoothware.net>
+ * Copyright (C) 2017 Mladen Milinkovic <max@smoothware.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,14 +20,15 @@
 #include "vobsubinputprocessdialog.h"
 #include "ui_vobsubinputprocessdialog.h"
 
-#include "mplayer/mp_msg.h"
-#include "mplayer/vobsub.h"
-#include "mplayer/spudec.h"
+#include <functional>
 
 #include <QDebug>
 #include <QPainter>
 #include <QKeyEvent>
 
+#include <KMessageBox>
+
+#include <QStringBuilder>
 #include <QDataStream>
 #include <QFile>
 #include <QSaveFile>
@@ -135,8 +135,9 @@ VobSubInputProcessDialog::Frame::processPieces()
 	QImage pieceBitmap = subPixmap.toImage();
 	int width = pieceBitmap.width();
 	int height = pieceBitmap.height();
-	int bgColor = pieceBitmap.pixel(0, 0);
+	int bgColor = qGray(pieceBitmap.pixel(0, 0));
 	int color;
+	const int colorOffset = 127;
 	PiecePtr piece;
 
 	pieces.clear();
@@ -157,13 +158,13 @@ VobSubInputProcessDialog::Frame::processPieces()
 		piece->pixels.append(QPoint(x, y));
 		pieceBitmap.setPixel(x, y, bgColor);
 
-		if(x < width - 1 && qGray(pieceBitmap.pixel(x + 1, y)) > 127)
+		if(x < width - 1 && qGray(pieceBitmap.pixel(x + 1, y)) > colorOffset)
 			cutPiece(x + 1, y);
-		if(x > 0 && qGray(pieceBitmap.pixel(x - 1, y)) > 127)
+		if(x > 0 && qGray(pieceBitmap.pixel(x - 1, y)) > colorOffset)
 			cutPiece(x - 1, y);
-		if(y < height - 1 && qGray(pieceBitmap.pixel(x, y + 1)) > 127)
+		if(y < height - 1 && qGray(pieceBitmap.pixel(x, y + 1)) > colorOffset)
 			cutPiece(x, y + 1);
-		if(y > 0 && qGray(pieceBitmap.pixel(x, y - 1)) > 127)
+		if(y > 0 && qGray(pieceBitmap.pixel(x, y - 1)) > colorOffset)
 			cutPiece(x, y - 1);
 	};
 
@@ -171,7 +172,7 @@ VobSubInputProcessDialog::Frame::processPieces()
 	for(int y = 0; y < height; y++) {
 		for(int x = 0; x < width; x++) {
 			color = qGray(pieceBitmap.pixel(x, y));
-			if(color > 127) {
+			if(color > colorOffset && color != bgColor) {
 				piece = new Piece(x, y);
 				cutPiece(x, y);
 				pieces.append(piece);
@@ -359,7 +360,7 @@ qHash(const VobSubInputProcessDialog::Piece &piece)
 
 
 // VobSubInputProcessDialog
-VobSubInputProcessDialog::VobSubInputProcessDialog(Subtitle *subtitle, void *vob, void *spu, QWidget *parent) :
+VobSubInputProcessDialog::VobSubInputProcessDialog(Subtitle *subtitle, QWidget *parent) :
 	QDialog(parent),
 	ui(new Ui::VobSubInputProcessDialog),
 	m_subtitle(subtitle),
@@ -395,8 +396,6 @@ VobSubInputProcessDialog::VobSubInputProcessDialog(Subtitle *subtitle, void *vob
 
 	ui->lineEdit->installEventFilter(this);
 	ui->lineEdit->setFocus();
-
-	QMetaObject::invokeMethod(this, "processFrames", Qt::QueuedConnection, Q_ARG(void *, vob), Q_ARG(void *, spu));
 }
 
 VobSubInputProcessDialog::~VobSubInputProcessDialog()
@@ -552,8 +551,14 @@ VobSubInputProcessDialog::eventFilter(QObject *obj, QEvent *event) /*override*/
 }
 
 void
-VobSubInputProcessDialog::processFrames(void *vob, void *spu)
+VobSubInputProcessDialog::processFrames(StreamProcessor *streamProcessor)
 {
+	connect(streamProcessor, &StreamProcessor::streamError, this, &VobSubInputProcessDialog::onStreamError);
+	connect(streamProcessor, &StreamProcessor::streamFinished, this, &VobSubInputProcessDialog::onStreamFinished);
+	connect(streamProcessor, &StreamProcessor::imageDataAvailable, this, &VobSubInputProcessDialog::onStreamData, Qt::BlockingQueuedConnection);
+
+	streamProcessor->start();
+
 	Frame::spaceCount = 0;
 	Frame::spaceStats.clear();
 
@@ -562,72 +567,36 @@ VobSubInputProcessDialog::processFrames(void *vob, void *spu)
 
 	ui->grpText->setDisabled(true);
 	ui->grpNavButtons->setDisabled(true);
-
-	QMetaObject::invokeMethod(this, "processNextFrame", Qt::QueuedConnection, Q_ARG(void *, vob), Q_ARG(void *, spu), Q_ARG(quint32, 0));
 }
 
 void
-VobSubInputProcessDialog::processNextFrame(void *vob, void *spu, quint32 lastStartPts)
+VobSubInputProcessDialog::onStreamData(const QPixmap &pixmap, quint64 msecStart, quint64 msecDuration)
 {
-	void *packet;
-	int timestamp;
-	int len;
+	FramePtr frame(new Frame());
+	frame->subShowTime.setMillisTime(double(msecStart));
+	frame->subHideTime.setMillisTime(double(msecStart + msecDuration));
+	frame->subPixmap = pixmap;
 
-	while((len = vobsub_get_next_packet(vob, &packet, &timestamp)) > 0) {
-		if(timestamp < 0)
-			continue;
+	ui->subtitleView->setPixmap(frame->subPixmap);
+	QCoreApplication::processEvents();
 
+	if(frame->processPieces()) {
+		frame->index = m_frames.length();
 		ui->progressBar->setMaximum(m_frames.length());
-
-		FramePtr frame(new Frame());
-
-		spudec_assemble(spu, reinterpret_cast<unsigned char*>(packet), len, timestamp);
-		spudec_heartbeat(spu, timestamp);
-
-		unsigned char const *image;
-		size_t image_size;
-		unsigned width, height, stride, start_pts, end_pts;
-		spudec_get_data(spu, &image, &image_size, &width, &height, &stride, &start_pts, &end_pts);
-
-		// skip this packet if it is another packet of a subtitle that was decoded from multiple mpeg packets.
-		if(start_pts == lastStartPts)
-			continue;
-
-		if(static_cast<unsigned>(timestamp) != start_pts)
-			qWarning() << "VobSub Line " << m_frames.length() << ": time stamp from .idx (" << timestamp << ") doesn't match time stamp from .sub (" << start_pts << ")\n";
-
-		frame->subShowTime.setMillisTime((double)start_pts / 90.);
-		frame->subHideTime.setMillisTime((double)end_pts / 90.);
-
-		QByteArray pgmBuffer;
-		pgmBuffer
-				.append("P5\n")
-				.append(QByteArray::number(width))
-				.append(" ")
-				.append(QByteArray::number(height))
-				.append(" ")
-				.append(QByteArray::number(255))
-				.append("\n")
-				.append(reinterpret_cast<const char *>(image), image_size);
-
-		if(!frame->subPixmap.loadFromData(pgmBuffer)) {
-			qWarning() << "VobSub Line " << m_frames.length() << ": Invalid pixmap - size: " << image_size << " bytes, " << width << "x" << height << " pixels\n";
-			continue;
-		}
-
-		// display current piece
-		ui->subtitleView->setPixmap(frame->subPixmap);
-		QCoreApplication::processEvents();
-
-		if(frame->processPieces()) {
-			frame->index = m_frames.length();
-			m_frames.append(frame);
-
-			QMetaObject::invokeMethod(this, "processNextFrame", Qt::QueuedConnection, Q_ARG(void *, vob), Q_ARG(void *, spu), Q_ARG(quint32, start_pts));
-			return;
-		}
+		m_frames.append(frame);
 	}
+}
 
+void
+VobSubInputProcessDialog::onStreamError(int /*code*/, const QString &message, const QString &debug)
+{
+	QString text = message % QStringLiteral("\n") % debug;
+	KMessageBox::error(this, text, i18n("VobSub Error"));
+}
+
+void
+VobSubInputProcessDialog::onStreamFinished()
+{
 	m_frameCurrent = m_frames.begin() - 1;
 
 	m_spaceWidth = 100;
