@@ -20,18 +20,27 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "../videoplayer/waveformat.h"
+#include "videoplayer/waveformat.h"
 
-#include <QObject>
+#include <QThread>
 #include <QString>
-
-#include <gst/gst.h>
+#include <QStringList>
+#include <QPixmap>
 
 QT_FORWARD_DECLARE_CLASS(QTimer)
 
+QT_FORWARD_DECLARE_STRUCT(AVFormatContext)
+typedef struct AVFormatContext AVFormatContext;
+QT_FORWARD_DECLARE_STRUCT(AVCodecContext)
+typedef struct AVCodecContext AVCodecContext;
+QT_FORWARD_DECLARE_STRUCT(AVStream)
+typedef struct AVStream AVStream;
+QT_FORWARD_DECLARE_STRUCT(SwrContext)
+typedef struct SwrContext SwrContext;
+
 namespace SubtitleComposer {
 
-class StreamProcessor : public QObject
+class StreamProcessor : public QThread
 {
 	Q_OBJECT
 
@@ -40,25 +49,30 @@ public:
 	virtual ~StreamProcessor();
 
 	bool open(const QString &filename);
-	bool initAudio(const int streamIndex, const WaveFormat &waveFormat);
-	bool initText(const int streamIndex);
-	void close();
+	bool initAudio(int streamIndex, const WaveFormat &waveFormat);
+	bool initImage(int streamIndex);
+	bool initText(int streamIndex);
+	Q_INVOKABLE void close();
+
+	QStringList listAudio();
+	QStringList listText();
+	QStringList listImage();
 
 	bool start();
 
 signals:
 	void audioDataAvailable(const void *buffer, const qint32 size, const WaveFormat *waveFormat, const quint64 msecStart, const quint64 msecDuration);
 	void textDataAvailable(const QString &text, const quint64 msecStart, const quint64 msecDuration);
+	void imageDataAvailable(const QPixmap &pixmap, const quint64 msecStart, const quint64 msecDuration);
 	void streamProgress(quint64 msecPosition, quint64 msecLength);
 	void streamError(int code, const QString &message, const QString &debug);
 	void streamFinished();
 
-private:
-	static void onAudioDataReady(GstElement *fakesrc, GstBuffer *buffer, GstPad *pad, gpointer userData);
-	static void onTextDataReady(GstElement *fakesrc, GstBuffer *buffer, GstPad *pad, gpointer userData);
-	static void onPadAdded(GstElement *decodebin, GstPad *pad, gpointer userData);
-	static gboolean onPadCheck(GstElement *decodebin, GstPad *pad, GstCaps *caps, gpointer userData);
-	void decoderMessageProc();
+protected:
+	int findStream(int streamType, int streamIndex, bool imageSub);
+	void processAudio();
+	void processText();
+    virtual void run() Q_DECL_OVERRIDE;
 
 private:
 	bool m_opened;
@@ -69,6 +83,10 @@ private:
 	int m_audioStreamCurrent;
 	WaveFormat m_audioStreamFormat;
 
+	bool m_imageReady;
+	int m_imageStreamIndex;
+	int m_imageStreamCurrent;
+
 	bool m_textReady;
 	int m_textStreamIndex;
 	int m_textStreamCurrent;
@@ -76,9 +94,12 @@ private:
 	quint64 m_streamPos;
 	quint64 m_streamLen;
 
-	GstPipeline *m_decodingPipeline;
-	GstBus *m_decodingBus;
-	QTimer *m_decodingTimer;
+	AVFormatContext *m_avFormat;
+	AVStream *m_avStream;
+	AVCodecContext *m_codecCtx;
+	SwrContext *m_swResample;
+	int m_audioSampleFormat;
+	uint64_t m_audioChannelLayout;
 };
 
 }
