@@ -21,7 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "../core/sstring.h"
+#include "core/sstring.h"
 
 #include <KTextEdit>
 
