@@ -1,38 +1,38 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "timeedit.h"
 #include "timevalidator.h"
 
-#include <QtCore/QTime>
-#include <QtCore/QEvent>
-#include <QtGui/QKeyEvent>
+#include <QTime>
+#include <QEvent>
+#include <QKeyEvent>
 
-#include <KDebug>
+#include <QDebug>
 
 TimeEdit::TimeEdit(QWidget *parent) :
 	QTimeEdit(parent),
 	m_secsStep(100)
 {
 	setDisplayFormat("hh:mm:ss.zzz");
-	setMinimumTime(QTime(0, 0, 0, 0));
-	setMaximumTime(QTime(23, 59, 59, 999));
+	setTimeRange(QTime(0, 0, 0, 0), QTime(23, 59, 59, 999));
 	setWrapping(false);
 	setAlignment(Qt::AlignHCenter);
 	setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
@@ -56,28 +56,28 @@ TimeEdit::setMSecsStep(int msecs)
 int
 TimeEdit::value() const
 {
-	return QTime().msecsTo(time());
+	return QTime(0, 0, 0, 0).msecsTo(time());
 }
 
 void
 TimeEdit::setValue(int value)
 {
-	if(wrapping())
-		setTime(QTime().addMSecs(value));
-	else {
-		if(value < QTime().msecsTo(minimumTime()))
+	if(wrapping()) {
+		setTime(QTime(0, 0, 0, 0).addMSecs(value));
+	} else {
+		if(value < QTime(0, 0, 0, 0).msecsTo(minimumTime()))
 			setTime(minimumTime());
-		else if(value >= QTime().msecsTo(maximumTime()))
+		else if(value >= QTime(0, 0, 0, 0).msecsTo(maximumTime()))
 			setTime(maximumTime());
 		else
-			setTime(QTime().addMSecs(value));
+			setTime(QTime(0, 0, 0, 0).addMSecs(value));
 	}
 }
 
 void
 TimeEdit::onTimeChanged(const QTime &time)
 {
-	emit valueChanged(QTime().msecsTo(time));
+	emit valueChanged(QTime(0, 0, 0, 0).msecsTo(time));
 }
 
 void
@@ -112,9 +112,9 @@ TimeEdit::stepBy(int steps)
 TimeEdit::StepEnabled
 TimeEdit::stepEnabled() const
 {
-	if(wrapping())
+	if(wrapping()) {
 		return QAbstractSpinBox::StepUpEnabled | QAbstractSpinBox::StepDownEnabled;
-	else {
+	} else {
 		QTime time = this->time();
 		if(time == minimumTime())
 			return QAbstractSpinBox::StepUpEnabled;
@@ -130,7 +130,7 @@ TimeEdit::keyPressEvent(QKeyEvent *event)
 {
 	int key = event->key();
 	if(key == Qt::Key_Return) {
-		emit valueEntered(QTime().msecsTo(time()));
+		emit valueEntered(QTime(0, 0, 0, 0).msecsTo(time()));
 	} else if(key == Qt::Key_Up) {
 		stepUp();
 	} else if(key == Qt::Key_Down) {
@@ -141,8 +141,9 @@ TimeEdit::keyPressEvent(QKeyEvent *event)
 	} else if(key == Qt::Key_PageDown) {
 		setCurrentSection(QDateTimeEdit::MSecSection);
 		stepDown();
-	} else
+	} else {
 		QTimeEdit::keyPressEvent(event);
+	}
 }
 
-#include "timeedit.moc"
+
