@@ -19,8 +19,8 @@
 
 #include "treeview.h"
 
-#include <QtCore/QTimer>
-#include <QtGui/QScrollBar>
+#include <QTimer>
+#include <QScrollBar>
 
 TreeView::TreeView(QWidget *parent) :
 	QTreeView(parent),
@@ -106,4 +106,4 @@ TreeView::onUpdateGeometriesTimeout()
 	QTreeView::updateGeometries();
 }
 
-#include "treeview.moc"
+
