@@ -20,9 +20,9 @@
  *   Boston, MA 02110-1301, USA.                                           *
  ***************************************************************************/
 
-#include <QtGui/QTreeView>
+#include <QTreeView>
 
-class QTimer;
+QT_FORWARD_DECLARE_CLASS(QTimer)
 
 class TreeView : public QTreeView
 {
